==> com.seafile.seadroid2_180_src.tar.gz: com.seafile.seadroid2_180_src.tar.gz/app/src/main/java/com/seafile/seadroid2/ui/camera_upload/AlbumBackupAdapter.java <==
package com.seafile.seadroid2.ui.camera_upload;

import android.content.AbstractThreadedSyncAdapter;
import android.content.ContentProviderClient;
import android.content.ContentResolver;
import android.content.Context;
import android.content.SyncResult;
import android.os.Bundle;

import com.seafile.seadroid2.account.Account;
import com.seafile.seadroid2.account.SupportAccountManager;
import com.seafile.seadroid2.framework.datastore.sp_livedata.AlbumBackupSharePreferenceHelper;
import com.seafile.seadroid2.framework.util.SLogs;
import com.seafile.seadroid2.framework.worker.BackgroundJobManagerImpl;

/**
 * Sync adapter for media upload.
 * <p/>
 * This class uploads images/videos from the gallery to the configured seafile account.
 * It is not called directly, but managed by the Android Sync Manager instead.
 */
public class AlbumBackupAdapter extends AbstractThreadedSyncAdapter {

    /**
     * Set up the sync adapter
     */
    public AlbumBackupAdapter(Context context) {
        /*
         * autoInitialize is set to false because we need to handle initialization
         * ourselves in performSync() (resetting the photo database).
         */
        super(context, false);
    }


    @Override
    public void onSecurityException(android.accounts.Account account, Bundle extras, String authority, SyncResult syncResult) {
        super.onSecurityException(account, extras, authority, syncResult);
        SLogs.d(AlbumBackupAdapter.class, "syncResult -> " + syncResult.toString());
    }

    @Override
    public boolean onUnsyncableAccount() {
        SLogs.d(AlbumBackupAdapter.class, "onUnsyncableAccount");
        return super.onUnsyncableAccount();
    }

    @Override
    public void onSyncCanceled(Thread thread) {
        super.onSyncCanceled(thread);
        SLogs.d(AlbumBackupAdapter.class, "onSyncCanceled ->" + thread.getName());
        BackgroundJobManagerImpl.getInstance().cancelMediaBackupChain();
    }

    @Override
    public void onSyncCanceled() {
        super.onSyncCanceled();
        SLogs.d(AlbumBackupAdapter.class, "onSyncCanceled");
        BackgroundJobManagerImpl.getInstance().cancelMediaBackupChain();
    }

    @Override
    public void onPerformSync(android.accounts.Account account,
                              Bundle extras, String authority,
                              ContentProviderClient provider,
                              SyncResult syncResult) {

        boolean isForce = extras.getBoolean(ContentResolver.SYNC_EXTRAS_MANUAL);
        SLogs.d(AlbumBackupAdapter.class, "onPerformSync, isForce -> " + isForce);
        Account seafileAccount = SupportAccountManager.getInstance().getSeafileAccount(account);

        // this should never occur, as camera upload is supposed to be disabled once the camera upload account signs out.
        if (!seafileAccount.hasValidToken()) {
            SLogs.d(AlbumBackupAdapter.class, "This account has no auth token. Disable camera upload.");
            syncResult.stats.numAuthExceptions++;

            // we're logged out on this account. disable camera upload.
            CameraUploadManager.getInstance().disableSpecialAccountCameraUpload(seafileAccount);
            return;
        }

        boolean isEnable = AlbumBackupSharePreferenceHelper.readBackupSwitch();
        if (!isEnable) {
            return;
        }

        // start
        BackgroundJobManagerImpl.getInstance().startMediaBackupChain(isForce);
    }
}

==> com.seafile.seadroid2_185_src.tar.gz: com.seafile.seadroid2_185_src.tar.gz/app/src/main/java/com/seafile/seadroid2/ui/camera_upload/AlbumBackupAdapter.java <==
package com.seafile.seadroid2.ui.camera_upload;

import android.content.AbstractThreadedSyncAdapter;
import android.content.ContentProviderClient;
import android.content.ContentResolver;
import android.content.Context;
import android.content.SyncResult;
import android.os.Bundle;

import com.seafile.seadroid2.account.Account;
import com.seafile.seadroid2.account.SupportAccountManager;
import com.seafile.seadroid2.framework.datastore.sp_livedata.AlbumBackupSharePreferenceHelper;
import com.seafile.seadroid2.framework.util.SLogs;
import com.seafile.seadroid2.framework.worker.BackgroundJobManagerImpl;

/**
 * Sync adapter for media upload.
 * <p/>
 * This class uploads images/videos from the gallery to the configured seafile account.
 * It is not called directly, but managed by the Android Sync Manager instead.
 */
public class AlbumBackupAdapter extends AbstractThreadedSyncAdapter {
    private final String TAG = "AlbumBackupAdapter";

    /**
     * Set up the sync adapter
     */
    public AlbumBackupAdapter(Context context) {
        /*
         * autoInitialize is set to false because we need to handle initialization
         * ourselves in performSync() (resetting the photo database).
         */
        super(context, false);
    }


    @Override
    public void onSecurityException(android.accounts.Account account, Bundle extras, String authority, SyncResult syncResult) {
        super.onSecurityException(account, extras, authority, syncResult);
        SLogs.d(TAG, "onSecurityException()", "syncResult -> " + syncResult.toString());
    }

    @Override
    public boolean onUnsyncableAccount() {
        SLogs.d(TAG, "onUnsyncableAccount()");
        return super.onUnsyncableAccount();
    }

    @Override
    public void onSyncCanceled(Thread thread) {
        super.onSyncCanceled(thread);
        SLogs.d(TAG, "onSyncCanceled()", thread.getName());
        BackgroundJobManagerImpl.getInstance().cancelMediaBackupChain();
    }

    @Override
    public void onSyncCanceled() {
        super.onSyncCanceled();
        SLogs.d(TAG, "onSyncCanceled()");
        BackgroundJobManagerImpl.getInstance().cancelMediaBackupChain();
    }

    @Override
    public void onPerformSync(android.accounts.Account account,
                              Bundle extras, String authority,
                              ContentProviderClient provider,
                              SyncResult syncResult) {

        boolean isForce = extras.getBoolean(ContentResolver.SYNC_EXTRAS_MANUAL);
        SLogs.d(TAG, "onPerformSync()", " isForce = " + isForce);

        Account seafileAccount = SupportAccountManager.getInstance().getSeafileAccount(account);

        // this should never occur, as camera upload is supposed to be disabled once the camera upload account signs out.
        if (!seafileAccount.hasValidToken()) {
            SLogs.d(TAG, "onPerformSync()", "This account has no auth token. Disable camera upload.");
            syncResult.stats.numAuthExceptions++;

            // we're logged out on this account. disable camera upload.
            CameraUploadManager.getInstance().disableSpecialAccountCameraUpload(seafileAccount);
            return;
        }

        boolean isEnable = AlbumBackupSharePreferenceHelper.readBackupSwitch();
        if (!isEnable) {
            return;
        }

        // start
        BackgroundJobManagerImpl.getInstance().startMediaBackupChain(isForce);
    }
}
